
#include "common.h"
#include "Sprite.h"
#include "TouchPanel.h"
#include "Sound.h"


// スプライト
enum
{
	SPR_PHOTO = 0,			// 背景
	SPR_MAX,
};

static sys::Sprite*	sprite;		// スプライト


// サウンドデータ
enum
{
	SOUND_SE = 0,			// SE
	SOUND_MAX,
};

static char*	sound_data[SOUND_MAX];		// サウンドデータ
static u32		sound_size[SOUND_MAX];		// サウンドデータサイズ
static int		se_track;					// SEトラック番号


/************
    初期化
 ************/
void	init_app(void)
{
	struct SprDef
	{
		const char*		tex_name;		// テクスチャファイル名
		SRect			coord;			// UV座標
	};

	static const
	SprDef	spr_def[SPR_MAX] =
			{
				{"photo.pkm",		{  0,   0, 640, 960}},		// 背景
			};

	sprite = new sys::Sprite[SPR_MAX];				// スプライト初期化
	for (int i = 0; i < SPR_MAX; i++) {
		sprite[i].set(sys::TexCache::RES_ASSET, spr_def[i].tex_name, &spr_def[i].coord);
	}


	sound_data[SOUND_SE] = (char*)sys::load_asset("se.ogg", &sound_size[SOUND_SE]);			// サウンドデータ読み込み
	se_track = 0;

	sys::SoundManager::play(4, "bgm.ogg", sys::SoundPlayer::FILE_ASSET, 0);					// BGM再生開始
}

/**********
    終了
 **********/
void	quit_app(void)
{
	sys::SoundManager::stop();
	for (int i = 0; i < SOUND_MAX; i++) {
		free(sound_data[i]);
	}

	delete[]	sprite;
}

/******************************
    稼働
		戻り値	アプリ続行か
 ******************************/
Bool	update_app(void)
{
	sprite[SPR_PHOTO].draw(0.0f, 0.0f);			// 背景

	if ( sys::TouchPanel[0].flag & sys::TouchManager::TRIGGER ) {
//		sys::SoundManager::play(se_track, sound_data[SOUND_SE], sound_size[SOUND_SE]);		// SE再生
		se_track = ++se_track % 4;
		if ( se_track % 2 ) {
			sys::SoundManager::stop(4, 3*60);												// BGM停止
		}
		else {
			sys::SoundManager::play(4, "bgm.ogg", sys::SoundPlayer::FILE_ASSET, 0);			// BGM再生開始
		}
	}

	return	TRUE;
}

/**************
    一時停止
 **************/
void	pause_app(void)
{
}

/**********
    再開
 **********/
void	resume_app(void)
{
}

/**************** End of File *************************************************/